@@ -1,15 +1,9 @@
 package Text::RecordParser;
 
-# $Id: RecordParser.pm,v 1.12 2006/05/18 18:53:41 kclark Exp $
-
 =head1 NAME
 
 Text::RecordParser - read record-oriented files
 
-=head1 VERSION
-
-This documentation refers to version 1.3.0.
-
 =head1 SYNOPSIS
 
   use Text::RecordParser;
@@ -97,7 +91,7 @@ use List::MoreUtils qw( uniq );
 use Readonly;
 use Text::ParseWords qw( parse_line );
 
-our $VERSION = version->new('1.3.0');
+our $VERSION = version->new('1.6.1');
 
 Readonly my $COMMA     => q{,};
 Readonly my $EMPTY_STR => q{};
@@ -244,8 +238,9 @@ Pass in an empty array reference to unset:
         $self->{'field_pos_ordered'} = [ @fields ];
 
         my %field_pos;
-        foreach my $i ( 0 .. $#fields ) {
-            $field_pos{ $fields[$i] } = $i;
+        for my $i ( 0 .. $#fields ) {
+            next unless $fields[ $i ];
+            $field_pos{ $fields[ $i ] } = $i;
         }
 
         $self->{'field_pos'}    = \%field_pos;
@@ -495,12 +490,13 @@ the C<bind_header> method will be implicitly called for you.
 =cut
 
     my $self   = shift;
-    my @fields = $self->field_list or return;
+    my @fields = $self->field_list     or return;
     my @row    = $self->fetchrow_array or return;
 
     my $i = 0;
     my %return;
     for my $field ( @fields ) {
+        next unless defined $row[ $i ];
         $return{ $field } = $row[ $i++ ];
         if ( my @aliases = $self->get_field_aliases( $field ) ) {
             $return{ $_ } = $return{ $field } for @aliases;
@@ -539,8 +535,8 @@ aliases will be created as additional accessor methods.
 =cut
 
     my $self   = shift;
-    my $row    = $self->fetchrow_hashref;
-    my @fields = $self->field_list or return;
+    my $row    = $self->fetchrow_hashref or return;
+    my @fields = $self->field_list       or return;
 
     push @fields, map { $self->get_field_aliases( $_ ) } @fields;
 
@@ -1151,7 +1147,7 @@ None known.  Please use http://rt.cpan.org/ for reporting bugs.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2006-9 Ken Youens-Clark.  All rights reserved.
+Copyright (C) 2006-10 Ken Youens-Clark.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
